@@ -20,7 +20,7 @@ class Category(object):
 		The method to get the display_label
 
 		Returns:
-			string: A string value
+			string: A string representing the display_label
 		"""
 
 		return self.__display_label
@@ -68,7 +68,7 @@ class Category(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -95,7 +95,7 @@ class Category(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
