@@ -16,13 +16,16 @@ class Profile(object):
 		self.__permissions_details = None
 		self.__name = None
 		self.__modified_by = None
+		self.__defaultview = None
 		self.__default = None
 		self.__description = None
 		self.__id = None
 		self.__category = None
+		self.__custom = None
 		self.__created_by = None
 		self.__sections = None
 		self.__delete = None
+		self.__permission_type = None
 		self.__key_modified = dict()
 
 	def get_display_label(self):
@@ -30,7 +33,7 @@ class Profile(object):
 		The method to get the display_label
 
 		Returns:
-			string: A string value
+			string: A string representing the display_label
 		"""
 
 		return self.__display_label
@@ -130,7 +133,7 @@ class Profile(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -178,12 +181,41 @@ class Profile(object):
 		self.__modified_by = modified_by
 		self.__key_modified['modified_by'] = 1
 
+	def get_defaultview(self):
+		"""
+		The method to get the defaultview
+
+		Returns:
+			DefaultView: An instance of DefaultView
+		"""
+
+		return self.__defaultview
+
+	def set_defaultview(self, defaultview):
+		"""
+		The method to set the value to defaultview
+
+		Parameters:
+			defaultview (DefaultView) : An instance of DefaultView
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.profiles.default_view import DefaultView
+		except Exception:
+			from .default_view import DefaultView
+
+		if defaultview is not None and not isinstance(defaultview, DefaultView):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: defaultview EXPECTED TYPE: DefaultView', None, None)
+		
+		self.__defaultview = defaultview
+		self.__key_modified['_default_view'] = 1
+
 	def get_default(self):
 		"""
 		The method to get the default
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the default
 		"""
 
 		return self.__default
@@ -207,7 +239,7 @@ class Profile(object):
 		The method to get the description
 
 		Returns:
-			string: A string value
+			string: A string representing the description
 		"""
 
 		return self.__description
@@ -231,7 +263,7 @@ class Profile(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -255,7 +287,7 @@ class Profile(object):
 		The method to get the category
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the category
 		"""
 
 		return self.__category
@@ -274,6 +306,30 @@ class Profile(object):
 		self.__category = category
 		self.__key_modified['category'] = 1
 
+	def get_custom(self):
+		"""
+		The method to get the custom
+
+		Returns:
+			bool: A bool representing the custom
+		"""
+
+		return self.__custom
+
+	def set_custom(self, custom):
+		"""
+		The method to set the value to custom
+
+		Parameters:
+			custom (bool) : A bool representing the custom
+		"""
+
+		if custom is not None and not isinstance(custom, bool):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: custom EXPECTED TYPE: bool', None, None)
+		
+		self.__custom = custom
+		self.__key_modified['custom'] = 1
+
 	def get_created_by(self):
 		"""
 		The method to get the created_by
@@ -332,7 +388,7 @@ class Profile(object):
 		The method to get the delete
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the delete
 		"""
 
 		return self.__delete
@@ -351,6 +407,30 @@ class Profile(object):
 		self.__delete = delete
 		self.__key_modified['_delete'] = 1
 
+	def get_permission_type(self):
+		"""
+		The method to get the permission_type
+
+		Returns:
+			string: A string representing the permission_type
+		"""
+
+		return self.__permission_type
+
+	def set_permission_type(self, permission_type):
+		"""
+		The method to set the value to permission_type
+
+		Parameters:
+			permission_type (string) : A string representing the permission_type
+		"""
+
+		if permission_type is not None and not isinstance(permission_type, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: permission_type EXPECTED TYPE: str', None, None)
+		
+		self.__permission_type = permission_type
+		self.__key_modified['permission_type'] = 1
+
 	def is_key_modified(self, key):
 		"""
 		The method to check if the user has modified the given key
@@ -359,7 +439,7 @@ class Profile(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
