@@ -57,8 +57,7 @@ class Utility(object):
                 split_lower = api_path_split[i].lower()
                 if split_lower == module_api_name.lower():
                     api_path_split[i] = module_api_name
-                elif split_lower in Constants.DEFAULT_MODULENAME_VS_APINAME.get(
-                        split_lower) and Constants.DEFAULT_MODULENAME_VS_APINAME.get(split_lower) is not None:
+                elif split_lower in Constants.DEFAULT_MODULENAME_VS_APINAME.get(split_lower) and Constants.DEFAULT_MODULENAME_VS_APINAME.get(split_lower) is not None:
                     api_path_split[i] = Constants.DEFAULT_MODULENAME_VS_APINAME.get(split_lower)
 
             api_path = "/".join(api_path_split)
@@ -104,8 +103,7 @@ class Utility(object):
                     Utility.new_file = True
                     Utility.fill_data_type()
                     api_supported_modules = Utility.get_modules(None)
-                    record_field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(
-                        record_field_details_path) else {}
+                    record_field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(record_field_details_path) else {}
 
                     record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME] = time.time() * 1000
 
@@ -114,8 +112,7 @@ class Utility(object):
                             record_field_details_json[module.lower()] = {}
                             Utility.write_to_file(file_path=record_field_details_path,
                                                   file_contents=record_field_details_json)
-                            field_details = Utility.get_fields_details(
-                                api_supported_modules[module][Constants.API_NAME])
+                            field_details = Utility.get_fields_details(api_supported_modules[module][Constants.API_NAME])
                             record_field_details_json = Initializer.get_json(record_field_details_path)
                             record_field_details_json[module.lower()] = field_details
                             Utility.write_to_file(file_path=record_field_details_path,
@@ -192,12 +189,9 @@ class Utility(object):
         with Utility.lock:
             record_field_details_json = Initializer.get_json(record_field_details_path)
 
-            if Initializer.get_initializer().sdk_config.get_auto_refresh_fields() and not Utility.new_file and not Utility.get_modified_modules and (
-                    Constants.FIELDS_LAST_MODIFIED_TIME not in record_field_details_json or Utility.force_refresh or (
-                    time.time() * 1000 - record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME]) > 3600000):
+            if Initializer.get_initializer().sdk_config.get_auto_refresh_fields() and not Utility.new_file and not Utility.get_modified_modules and (Constants.FIELDS_LAST_MODIFIED_TIME not in record_field_details_json or Utility.force_refresh or (time.time() * 1000 - record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME]) > 3600000):
                 Utility.get_modified_modules = True
-                last_modified_time = record_field_details_json[
-                    Constants.FIELDS_LAST_MODIFIED_TIME] if not Utility.force_refresh and Constants.FIELDS_LAST_MODIFIED_TIME in record_field_details_json else None
+                last_modified_time = record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME] if not Utility.force_refresh and Constants.FIELDS_LAST_MODIFIED_TIME in record_field_details_json else None
                 Utility.modify_fields(record_field_details_path, last_modified_time)
                 Utility.get_modified_modules = False
 
@@ -222,15 +216,13 @@ class Utility(object):
 
     @staticmethod
     def verify_module_api_name(module_api_name):
-        if module_api_name is not None and Constants.DEFAULT_MODULENAME_VS_APINAME.get(
-                module_api_name.lower()) is not None:
+        if module_api_name is not None and Constants.DEFAULT_MODULENAME_VS_APINAME.get(module_api_name.lower()) is not None:
             return Constants.DEFAULT_MODULENAME_VS_APINAME.get(module_api_name.lower())
 
         record_field_details_path = Utility.get_file_name()
         if os.path.exists(record_field_details_path):
             fields_json = Initializer.get_json(record_field_details_path)
-            if Constants.SDK_MODULE_METADATA in fields_json and module_api_name.lower() in fields_json[
-                Constants.SDK_MODULE_METADATA]:
+            if Constants.SDK_MODULE_METADATA in fields_json and module_api_name.lower() in fields_json[Constants.SDK_MODULE_METADATA]:
                 return fields_json[Constants.SDK_MODULE_METADATA][module_api_name.lower()][Constants.API_NAME]
 
         return module_api_name
@@ -240,8 +232,7 @@ class Utility(object):
         subform_modules = []
         fields_json = record_field_details_json[module.lower()]
         for key, value in fields_json.items():
-            if Constants.SUBFORM in value and value[Constants.SUBFORM] and (
-                    value[Constants.MODULE]).lower() in record_field_details_json:
+            if Constants.SUBFORM in value and value[Constants.SUBFORM] and (value[Constants.MODULE]).lower() in record_field_details_json:
                 subform_modules.append(value[Constants.MODULE])
 
         del record_field_details_json[module.lower()]
@@ -254,8 +245,7 @@ class Utility(object):
     def get_file_name():
         import zcrmsdk.src.com.zoho.crm.api.util.converter as Converter
 
-        return os.path.join(Initializer.get_initializer().resource_path, Constants.FIELD_DETAILS_DIRECTORY,
-                            Converter.Converter.get_encoded_file_name())
+        return os.path.join(Initializer.get_initializer().resource_path, Constants.FIELD_DETAILS_DIRECTORY,Converter.Converter.get_encoded_file_name())
 
     @staticmethod
     def get_related_lists(related_module_name, module_api_name, common_api_handler):
@@ -263,8 +253,7 @@ class Utility(object):
             try:
                 is_new_data = False
                 key = (module_api_name + Constants.UNDERSCORE + Constants.RELATED_LISTS).lower()
-                resources_path = os.path.join(Initializer.get_initializer().resource_path,
-                                              Constants.FIELD_DETAILS_DIRECTORY)
+                resources_path = os.path.join(Initializer.get_initializer().resource_path,Constants.FIELD_DETAILS_DIRECTORY)
 
                 if not os.path.exists(resources_path):
                     os.makedirs(resources_path)
@@ -275,16 +264,14 @@ class Utility(object):
                     record_field_details_path)):
                     is_new_data = True
                     related_list_values = Utility.get_related_list_details(module_api_name)
-                    record_field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(
-                        record_field_details_path) else {}
+                    record_field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(record_field_details_path) else {}
                     record_field_details_json[key] = related_list_values
                     Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
 
                 record_field_details_json = Initializer.get_json(record_field_details_path)
                 module_related_list = record_field_details_json[key]
 
-                if not Utility.check_related_list_exists(related_module_name, module_related_list,
-                                                         common_api_handler) and not is_new_data:
+                if not Utility.check_related_list_exists(related_module_name, module_related_list,common_api_handler) and not is_new_data:
                     del record_field_details_json[key]
                     Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
 
@@ -302,8 +289,7 @@ class Utility(object):
     @staticmethod
     def check_related_list_exists(related_module_name, module_related_list_array, common_api_handler):
         for related_list_jo in module_related_list_array:
-            if related_list_jo[Constants.API_NAME] is not None and related_list_jo[
-                Constants.API_NAME].lower() == related_module_name.lower():
+            if related_list_jo[Constants.API_NAME] is not None and related_list_jo[Constants.API_NAME].lower() == related_module_name.lower():
                 if related_list_jo[Constants.HREF] == Constants.NULL_VALUE:
                     raise SDKException(code=Constants.UNSUPPORTED_IN_API,
                                        message=common_api_handler.get_http_method() + ' ' + common_api_handler.get_api_path() + Constants.UNSUPPORTED_IN_API_MESSAGE)
