@@ -34,7 +34,7 @@ class VariablesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/variables'
+		api_path = api_path + '/crm/v2.1/settings/variables'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
@@ -69,7 +69,7 @@ class VariablesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/variables'
+		api_path = api_path + '/crm/v2.1/settings/variables'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
@@ -106,7 +106,7 @@ class VariablesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/variables'
+		api_path = api_path + '/crm/v2.1/settings/variables'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
@@ -138,7 +138,7 @@ class VariablesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/variables'
+		api_path = api_path + '/crm/v2.1/settings/variables'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
 		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
@@ -172,7 +172,7 @@ class VariablesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/variables/'
+		api_path = api_path + '/crm/v2.1/settings/variables/'
 		api_path = api_path + str(id)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
@@ -212,7 +212,7 @@ class VariablesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/variables/'
+		api_path = api_path + '/crm/v2.1/settings/variables/'
 		api_path = api_path + str(id)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
@@ -244,7 +244,7 @@ class VariablesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/variables/'
+		api_path = api_path + '/crm/v2.1/settings/variables/'
 		api_path = api_path + str(id)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
@@ -278,7 +278,7 @@ class VariablesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/variables/'
+		api_path = api_path + '/crm/v2.1/settings/variables/'
 		api_path = api_path + str(api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
@@ -318,7 +318,7 @@ class VariablesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/variables/'
+		api_path = api_path + '/crm/v2.1/settings/variables/'
 		api_path = api_path + str(api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
